@@ -19,7 +19,7 @@
 ;; URL:              https://github.com/meedstrom/el-job
 ;; Created:          2024-10-30
 ;; Keywords:         processes
-;; Package-Version:  2.4.0
+;; Package-Version:  2.4.1
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -55,10 +55,6 @@
 ;;   features, so we can reuse that to start the subprocesses nigh-instantly.
 ;;   Could even simplify to a sentinel-based workflow then, no polling.
 
-;; - Improve the error message in some cases when it is unhelpful and only says
-;;   something like "Error running timer: listp Error:".  I surmise the process
-;;   buffer contents are not in a Lisp-readable form then.
-
 (require 'cl-lib)
 (require 'el-job-child)
 
@@ -649,17 +645,15 @@ more input in the queue."
     (el-job--with job
         ( .busy .ready .input-sets .past-elapsed .result-sets .stderr
           .queued-inputs .timestamps .id .finish-times .callback )
-      (condition-case err (let ((output (read (buffer-string))))
-                            (setq finish-time (caar output))
-                            (setq durations (cdar output))
-                            (setq results (cdr output)))
+      (condition-case _ (let ((output (read (buffer-string))))
+                          (setq finish-time (caar output))
+                          (setq durations (cdar output))
+                          (setq results (cdr output)))
         (( error )
-         (el-job--unhide-buffer .stderr)
          (dolist (proc (append .busy .ready))
-           (el-job--unhide-buffer (process-buffer proc))
            (delete-process proc))
-         (error "In buffer %s: problems reading child output: %S"
-                (current-buffer) err)))
+         (error "In buffer %s: problems reading child output: %s"
+                (current-buffer) (buffer-string))))
       (push finish-time .finish-times)
       (setf .busy (delq proc .busy))
       (push proc .ready)
@@ -708,11 +702,6 @@ same ID still has the benchmarks table and possibly queued input."
     (setf .busy nil)
     (setf .ready nil)))
 
-(defun el-job--unhide-buffer (buffer)
-  "Rename BUFFER to omit initial space, and return the new name."
-  (with-current-buffer buffer
-    (rename-buffer (string-trim-left (buffer-name)))))
-
 
 ;;; Tools / public API
 
